@@ -6,7 +6,6 @@ module.exports = {
   },
   moduleNameMapper: {
     '\\.(css|less)$': '<rootDir>/__mocks__/styleMock.js',
-    '^react$': '<rootDir>/node_modules/react',
-    '^react-dom$': '<rootDir>/node_modules/react-dom',
   },
+  transformIgnorePatterns: [`/node_modules/(?!nanoid)`],
 };
