@@ -134,6 +134,41 @@ describe('SchemaField', () => {
     });
   });
 
+  describe('Custom type component', () => {
+    const CustomStringField = function () {
+      return <div id='custom-type' />;
+    };
+
+    it('should use custom type component', () => {
+      const fields = { StringField: CustomStringField };
+      const { node } = createFormComponent({
+        schema: { type: 'string' },
+        fields,
+      });
+
+      expect(node.querySelectorAll('#custom-type')).to.have.length.of(1);
+    });
+  });
+
+  describe('Custom id component', () => {
+    const CustomIdField = function () {
+      return <div id='custom-id' />;
+    };
+
+    it('should use custom id compnent', () => {
+      const fields = { '/schemas/custom-id': CustomIdField };
+      const { node } = createFormComponent({
+        schema: {
+          $id: '/schemas/custom-id',
+          type: 'string',
+        },
+        fields,
+      });
+
+      expect(node.querySelectorAll('#custom-id')).to.have.length.of(1);
+    });
+  });
+
   describe('ui:field support', () => {
     class MyObject extends Component {
       constructor(props) {
@@ -440,6 +475,37 @@ describe('SchemaField', () => {
       expect(matches[0].textContent).to.contain('test');
     });
 
+    it('should ignore errors for top level anyOf/oneOf and show only one in child schema', () => {
+      const testSchema = {
+        type: 'object',
+        properties: {
+          foo: {
+            anyOf: [
+              {
+                type: 'boolean',
+              },
+              {
+                type: 'array',
+                items: {
+                  type: 'string',
+                },
+              },
+            ],
+          },
+        },
+      };
+      const { node } = createFormComponent({
+        schema: testSchema,
+        uiSchema,
+        customValidate,
+      });
+      Simulate.submit(node);
+
+      const matches = node.querySelectorAll('form .form-group .form-group .text-danger');
+      expect(matches).to.have.length.of(1);
+      expect(matches[0].textContent).to.contain('test');
+    });
+
     it('should pass errors to custom FieldErrorTemplate', () => {
       const customFieldError = (props) => {
         return <div className='custom-field-error'>{props.errors}</div>;
@@ -653,4 +719,50 @@ describe('SchemaField', () => {
       expect(customMatches[0].textContent).to.contain(helpText);
     });
   });
+
+  describe('markdown', () => {
+    const schema = {
+      type: 'object',
+      properties: {
+        foo: { type: 'string' },
+      },
+    };
+    const descText = 'Make things **bold** or *italic*. Embed snippets of `code`.';
+
+    it('should render description with markdown', () => {
+      const { node } = createFormComponent({
+        schema,
+        uiSchema: {
+          foo: {
+            'ui:description': descText,
+            'ui:enableMarkdownInDescription': true,
+          },
+        },
+      });
+
+      const { innerHTML } = node.querySelector('form .form-group .form-group .field-description');
+
+      expect(innerHTML).to.contains('<strong>');
+      expect(innerHTML).to.contains('<em>');
+      expect(innerHTML).to.contains('<code>');
+    });
+
+    it('should render description without html tags', () => {
+      const { node } = createFormComponent({
+        schema,
+        uiSchema: {
+          foo: {
+            'ui:description': descText,
+          },
+        },
+      });
+
+      const { innerHTML, textContent } = node.querySelector('form .form-group .form-group .field-description');
+
+      expect(innerHTML).to.not.contains('<strong>');
+      expect(innerHTML).to.not.contains('<em>');
+      expect(innerHTML).to.not.contains('<code>');
+      expect(textContent).to.contains(descText);
+    });
+  });
 });
