@@ -32,9 +32,13 @@ describe('oneOf', () => {
     expect(node.querySelectorAll('select')).to.have.length.of(0);
   });
 
-  it('should render a select element if the oneOf keyword is present', () => {
+  it('should render a select element if the oneOf keyword is present, merges top level required', () => {
     const schema = {
       type: 'object',
+      required: ['baz'],
+      properties: {
+        baz: { type: 'number' },
+      },
       oneOf: [
         {
           properties: {
@@ -53,8 +57,44 @@ describe('oneOf', () => {
       schema,
     });
 
+    console.log(node.innerHTML);
+
     expect(node.querySelectorAll('select')).to.have.length.of(1);
     expect(node.querySelector('select').id).eql('root__oneof_select');
+    expect(node.querySelectorAll('span.required')).to.have.length.of(1);
+  });
+
+  it('should render a select element if the oneOf keyword is present, merges top level and oneOf required', () => {
+    const schema = {
+      type: 'object',
+      required: ['baz'],
+      properties: {
+        baz: { type: 'number' },
+      },
+      oneOf: [
+        {
+          required: ['foo'],
+          properties: {
+            foo: { type: 'string' },
+          },
+        },
+        {
+          properties: {
+            bar: { type: 'string' },
+          },
+        },
+      ],
+    };
+
+    const { node } = createFormComponent({
+      schema,
+    });
+
+    console.log(node.innerHTML);
+
+    expect(node.querySelectorAll('select')).to.have.length.of(1);
+    expect(node.querySelector('select').id).eql('root__oneof_select');
+    expect(node.querySelectorAll('span.required')).to.have.length.of(2);
   });
 
   it('should assign a default value and set defaults on option change', () => {
@@ -1148,7 +1188,6 @@ describe('oneOf', () => {
     });
     const outerOneOf = node.querySelector('select#root_0__oneof_select');
     expect(outerOneOf.value).eql('1');
-    console.log(node.innerHTML);
     const innerOneOf = node.querySelector('select#root_0_ipsum__oneof_select');
     expect(innerOneOf.value).eql('1');
   });
